cumulusci.tasks.bulkdata.tests package
======================================

Submodules
----------


.. automodule:: cumulusci.tasks.bulkdata.tests.dummy_data_factory
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.tests.mock_data_factory_without_mapping
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.tests.test_base_generate_data_tasks
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.tests.test_bulkdata
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.tests.test_delete
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.tests.test_factory_utils
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.tests.test_generate_and_load
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.bulkdata.tests.test_utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.bulkdata.tests
   :members:
   :undoc-members:
   :show-inheritance:
